@@ -214,7 +214,7 @@ def freehub_update():
     print('Files to install:',files)
     for f in files:
         if f.endswith('.whl'):
-            os.system('pip3 install %s'%(f))
+            os.system('pip3 install %s --user'%(f))
     if not files:
         logging.warning('Noting to install')
 
