@@ -24,6 +24,9 @@ class Cli:
     def install(cls,address:str):
         raise NotImplementedError(cls.install)
     @classmethod
+    def fetch(cls,address:str):
+        raise NotImplementedError(cls.fetch)
+    @classmethod
     def publish(cls,address,str):
         raise NotImplementedError(cls.publish)
     @classmethod
@@ -116,7 +119,7 @@ class Cli:
         print(kwargs)
     @classmethod
     def version(cls):
-        print('freehub-0.1.1.5')
+        print('freehub-0.1.2.7')
     class branch:
         @classmethod
         def search(cls,pattern:str):
