@@ -109,6 +109,7 @@ def copy_repo_files_to_dir(src,dst,exclude_git=True):
             shutil.copy(child_path,dst_child_path)
 def copy_to_repo(src_path,repo_dir,relative_path,overwrite=True):
     '''copy a file or dir into relative path under repo_dir'''
+    src_path=os.path.abspath(src_path)
     dst_path=join_path(repo_dir,relative_path)
     dst_parent = os.path.dirname(dst_path)
     if not os.path.exists(dst_parent):
@@ -121,8 +122,6 @@ def copy_to_repo(src_path,repo_dir,relative_path,overwrite=True):
                     shutil.rmtree(dst_path)
                     time.sleep(1e-10)
                 else:
-                    # will raise an error
-                    # shutil.copytree(src_path, dst_path)
                     raise FileExistsError('% already exists and overwrite is %s'%(dst_path,overwrite))
             return shutil.copytree(src_path,dst_path)
         else:
